==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/ThisMonthExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { ThisMonthExpressionDescription } from "./ThisMonthExpressionDescription";
/**
 * @hidden
 */
export let ThisMonthExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class ThisMonthExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (ThisMonthExpressionDescriptionMetadata.a == null) {
                ThisMonthExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ThisMonthExpressionDescriptionMetadata.c(ThisMonthExpressionDescriptionMetadata.a);
            }
            if (a.j(ThisMonthExpressionDescriptionMetadata.a)) {
                return;
            }
            a.y(ThisMonthExpressionDescriptionMetadata.a);
        }
        static c(a) {
            WrapperExpressionDescriptionMetadata.c(a);
        }
        static d(a) {
            ThisMonthExpressionDescriptionMetadata.b(a);
            a.aa("ThisMonthExpression", () => new ThisMonthExpressionDescription());
            a.z("ThisMonthExpression", ThisMonthExpressionDescriptionMetadata.a);
        }
    }
    ThisMonthExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(ThisMonthExpressionDescriptionMetadata, 'ThisMonthExpressionDescriptionMetadata');
    ThisMonthExpressionDescriptionMetadata.a = null;
    return ThisMonthExpressionDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ThisMonthExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { ThisMonthExpressionDescription } from "./ThisMonthExpressionDescription";
/**
 * @hidden
 */
export let ThisMonthExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class ThisMonthExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (ThisMonthExpressionDescriptionMetadata.a == null) {
                ThisMonthExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ThisMonthExpressionDescriptionMetadata.c(ThisMonthExpressionDescriptionMetadata.a);
            }
            if (a.k(ThisMonthExpressionDescriptionMetadata.a)) {
                return;
            }
            a.aa(ThisMonthExpressionDescriptionMetadata.a);
        }
        static c(a) {
            WrapperExpressionDescriptionMetadata.c(a);
        }
        static d(a) {
            ThisMonthExpressionDescriptionMetadata.b(a);
            a.ac("ThisMonthExpression", () => new ThisMonthExpressionDescription());
            a.ab("ThisMonthExpression", ThisMonthExpressionDescriptionMetadata.a);
        }
    }
    ThisMonthExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(ThisMonthExpressionDescriptionMetadata, 'ThisMonthExpressionDescriptionMetadata');
    ThisMonthExpressionDescriptionMetadata.a = null;
    return ThisMonthExpressionDescriptionMetadata;
})();
